@@ -15,8 +15,8 @@
 #'   greater than 0.05.
 #'
 #' @references
-#' Hosmer, D. W., & Lemeshow, S. (2000). Applied Logistic Regression. Hoboken,
-#' NJ, USA: John Wiley & Sons, Inc. \doi{10.1002/0471722146}
+#' Hosmer, D. W., and Lemeshow, S. (2000). Applied Logistic Regression. Hoboken,
+#' NJ, USA: John Wiley and Sons, Inc. \doi{10.1002/0471722146}
 #'
 #' @examples
 #' model <- glm(vs ~ wt + mpg, data = mtcars, family = "binomial")
@@ -61,3 +61,30 @@ performance_hosmer <- function(model, n_bins = 10) {
   class(hoslem) <- c("performance_hosmer", "list")
   hoslem
 }
+
+
+
+# methods ---------------------------------
+
+#' @export
+print.performance_hosmer <- function(x, ...) {
+  insight::print_color("# Hosmer-Lemeshow Goodness-of-Fit Test\n\n", "blue")
+
+  v1 <- sprintf("%.3f", x$chisq)
+  v2 <- sprintf("%i    ", x$df)
+  v3 <- sprintf("%.3f", x$p.value)
+
+  space <- max(nchar(c(v1, v2, v3)))
+
+  cat(sprintf("  Chi-squared: %*s\n", space, v1))
+  cat(sprintf("           df: %*s\n", space, v2))
+  cat(sprintf("      p-value: %*s\n\n", space, v3))
+
+  if (x$p.value >= 0.05) {
+    message("Summary: model seems to fit well.")
+  } else {
+    message("Summary: model does not fit well.")
+  }
+
+  invisible(x)
+}
