@@ -1,6 +1,7 @@
 #' @rdname display.performance_model
 #' @export
-print_md.performance_model <- function(x, digits = 2, ...) {
+print_md.performance_model <- function(x, digits = 2, caption = "Indices of model performance", layout = "horizontal", ...) {
+  layout <- match.arg(layout, choices = c("horizontal", "vertical"))
   formatted_table <- format(
     x = x,
     digits = digits,
@@ -8,20 +9,27 @@ print_md.performance_model <- function(x, digits = 2, ...) {
     ...
   )
 
+  # switch to vertical layout
+  if (layout == "vertical") {
+    formatted_table <- datawizard::rownames_as_column(as.data.frame(t(formatted_table)), "Metric")
+    colnames(formatted_table)[2] <- "Value"
+  }
+
   insight::export_table(
     x = formatted_table,
     digits = digits,
     format = "markdown",
-    caption = "Indices of model performance",
+    caption = caption,
     align = "firstleft",
     ...
   )
 }
 
 
+#' @rdname display.performance_model
 #' @export
-print_md.compare_performance <- function(x, digits = 2, ...) {
-  table_caption <- "Comparison of Model Performance Indices"
+print_md.compare_performance <- function(x, digits = 2, caption = "Comparison of Model Performance Indices", layout = "horizontal", ...) {
+  layout <- match.arg(layout, choices = c("horizontal", "vertical"))
   formatted_table <- format(x = x, digits = digits, format = "markdown", ...)
 
   if ("Performance_Score" %in% colnames(x)) {
@@ -30,11 +38,18 @@ print_md.compare_performance <- function(x, digits = 2, ...) {
     footer <- NULL
   }
 
+  # switch to vertical layout
+  if (layout == "vertical") {
+    formatted_table <- datawizard::rownames_as_column(as.data.frame(t(formatted_table)), "Metric")
+    formatted_table <- datawizard::row_to_colnames(formatted_table)
+    colnames(formatted_table)[1] <- "Metric"
+  }
+
   insight::export_table(
     x = formatted_table,
     digits = digits,
     format = "markdown",
-    caption = table_caption,
+    caption = caption,
     footer = footer,
     align = "firstleft"
   )
@@ -42,8 +57,8 @@ print_md.compare_performance <- function(x, digits = 2, ...) {
 
 
 #' @export
-print_html.compare_performance <- function(x, digits = 2, ...) {
-  table_caption <- "Comparison of Model Performance Indices"
+print_html.compare_performance <- function(x, digits = 2, caption = "Comparison of Model Performance Indices", layout = "horizontal", ...) {
+  layout <- match.arg(layout, choices = c("horizontal", "vertical"))
   formatted_table <- format(x = x, digits = digits, format = "html", ...)
 
   if ("Performance_Score" %in% colnames(x)) {
@@ -52,11 +67,18 @@ print_html.compare_performance <- function(x, digits = 2, ...) {
     footer <- NULL
   }
 
+  # switch to vertical layout
+  if (layout == "vertical") {
+    formatted_table <- datawizard::rownames_as_column(as.data.frame(t(formatted_table)), "Metric")
+    formatted_table <- datawizard::row_to_colnames(formatted_table)
+    colnames(formatted_table)[1] <- "Metric"
+  }
+
   insight::export_table(
     x = formatted_table,
     digits = digits,
     format = "html",
-    caption = table_caption,
+    caption = caption,
     footer = footer,
     align = "firstleft"
   )
