@@ -33,15 +33,15 @@
 #'  \item Hox, J. J. (2010). Multilevel analysis: techniques and applications
 #'  (2nd ed). New York: Routledge.
 #'
-#'  \item Johnson, P. C. D. (2014). Extension of Nakagawa & Schielzeth’s R2 GLMM
+#'  \item Johnson, P. C. D. (2014). Extension of Nakagawa and Schielzeth’s R2 GLMM
 #'  to random slopes models. Methods in Ecology and Evolution, 5(9), 944–946.
 #'  \doi{10.1111/2041-210X.12225}
 #'
-#'  \item Nakagawa, S., & Schielzeth, H. (2013). A general and simple method for
+#'  \item Nakagawa, S., and Schielzeth, H. (2013). A general and simple method for
 #'  obtaining R2 from generalized linear mixed-effects models. Methods in
 #'  Ecology and Evolution, 4(2), 133–142. \doi{10.1111/j.2041-210x.2012.00261.x}
 #'
-#'  \item Nakagawa, S., Johnson, P. C. D., & Schielzeth, H. (2017). The
+#'  \item Nakagawa, S., Johnson, P. C. D., and Schielzeth, H. (2017). The
 #'  coefficient of determination R2 and intra-class correlation coefficient from
 #'  generalized linear mixed-effects models revisited and expanded. Journal of
 #'  The Royal Society Interface, 14(134), 20170213. \doi{10.1098/rsif.2017.0213}
@@ -102,7 +102,7 @@ r2_nakagawa <- function(model, by_group = FALSE, tolerance = 1e-5) {
     group_names <- insight::find_random(model, split_nested = TRUE, flatten = TRUE)
 
     # compute r2 by level
-    r2_random <- 1 - (vars$var.intercept / vars_null$var.intercept)
+    r2_random <- 1 - (vars$var.intercept[group_names] / vars_null$var.intercept[group_names])
     r2_fixed <- 1 - (vars$var.residual / vars_null$var.residual)
 
     out <- data.frame(
@@ -115,7 +115,7 @@ r2_nakagawa <- function(model, by_group = FALSE, tolerance = 1e-5) {
     out
   } else {
     # Calculate R2 values
-    if (.is_empty_object(vars$var.random) || is.na(vars$var.random)) {
+    if (insight::is_empty_object(vars$var.random) || is.na(vars$var.random)) {
       # if no random effect variance, return simple R2
       insight::print_color("Random effect variances not available. Returned R2 does not account for random effects.\n", "red")
       r2_marginal <- vars$var.fixed / (vars$var.fixed + vars$var.residual)
