@@ -1,4 +1,4 @@
-if (require("testthat") && require("performance")) {
+if (requiet("testthat") && requiet("performance")) {
   test_that("item_split_half", {
     data(iris)
     x <- iris[, 1:4]
@@ -10,5 +10,12 @@ if (require("testthat") && require("performance")) {
       ),
       tolerance = 1e-3
     )
+
+    x <- iris[, 1:2]
+    expect_equal(
+      item_split_half(x),
+      list(splithalf = -0.11757, spearmanbrown = -0.26647),
+      tolerance = 1e-3
+    )
   })
 }
