@@ -3,7 +3,7 @@ if (requiet("testthat") && requiet("performance") && requiet("metafor")) {
 
   test_that("model_performance.rma", {
     model <- rma(yi, vi, data = dat, method = "REML")
-    mp <- model_performance(model)
+    mp <- model_performance(model, estimator = "REML")
     expect_null(mp$R2)
     expect_equal(mp$AIC, 28.40474, tolerance = 1e-3)
     expect_equal(mp$I2, 0.9222139, tolerance = 1e-3)
@@ -15,7 +15,7 @@ if (requiet("testthat") && requiet("performance") && requiet("metafor")) {
 
   test_that("model_performance.rma", {
     model <- rma(yi, vi, mods = cbind(ablat, year), data = dat)
-    mp <- model_performance(model)
+    mp <- model_performance(model, estimator = "REML")
     expect_equal(mp$R2, 0.6463217, tolerance = 1e-3)
     expect_equal(mp$AIC, 24.21375, tolerance = 1e-3)
     expect_equal(mp$I2, 0.719778, tolerance = 1e-3)
